(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('vue-typed-mixins'), require('mapbox-gl'), require('@mapbox/mapbox-gl-geocoder'), require('my-deferred')) :
    typeof define === 'function' && define.amd ? define(['exports', 'vue-typed-mixins', 'mapbox-gl', '@mapbox/mapbox-gl-geocoder', 'my-deferred'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global.VueMapboxGl = {}, global.mixins, global.mapboxgl, global.MapboxGeocoder, global.Deferred));
}(this, (function (exports, mixins, mapboxgl, MapboxGeocoder, Deferred) { 'use strict';

    function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

    var mixins__default = /*#__PURE__*/_interopDefaultLegacy(mixins);
    var mapboxgl__default = /*#__PURE__*/_interopDefaultLegacy(mapboxgl);
    var MapboxGeocoder__default = /*#__PURE__*/_interopDefaultLegacy(MapboxGeocoder);
    var Deferred__default = /*#__PURE__*/_interopDefaultLegacy(Deferred);

    /*! *****************************************************************************
    Copyright (c) Microsoft Corporation.

    Permission to use, copy, modify, and/or distribute this software for any
    purpose with or without fee is hereby granted.

    THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
    REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
    AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
    INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
    LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
    OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
    PERFORMANCE OF THIS SOFTWARE.
    ***************************************************************************** */

    var __assign = function() {
        __assign = Object.assign || function __assign(t) {
            for (var s, i = 1, n = arguments.length; i < n; i++) {
                s = arguments[i];
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
            }
            return t;
        };
        return __assign.apply(this, arguments);
    };

    function __rest(s, e) {
        var t = {};
        for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
            t[p] = s[p];
        if (s != null && typeof Object.getOwnPropertySymbols === "function")
            for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
                if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                    t[p[i]] = s[p[i]];
            }
        return t;
    }

    function __awaiter(thisArg, _arguments, P, generator) {
        function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
        return new (P || (P = Promise))(function (resolve, reject) {
            function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
            function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
            function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
            step((generator = generator.apply(thisArg, _arguments || [])).next());
        });
    }

    function __generator(thisArg, body) {
        var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
        return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
        function verb(n) { return function (v) { return step([n, v]); }; }
        function step(op) {
            if (f) throw new TypeError("Generator is already executing.");
            while (_) try {
                if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
                if (y = 0, t) op = [op[0] & 2, t.value];
                switch (op[0]) {
                    case 0: case 1: t = op; break;
                    case 4: _.label++; return { value: op[1], done: false };
                    case 5: _.label++; y = op[1]; op = [0]; continue;
                    case 7: op = _.ops.pop(); _.trys.pop(); continue;
                    default:
                        if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                        if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                        if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                        if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                        if (t[2]) _.ops.pop();
                        _.trys.pop(); continue;
                }
                op = body.call(thisArg, _);
            } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
            if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
        }
    }

    var injectMap = mixins__default['default']().extend({
        inject: {
            $map: { default: null },
        },
        computed: {
            map: {
                get: function () {
                    return this.$map();
                },
            }
        },
    });

    /**
     * Map a mapbox element's events to the given vue element
     *
     * @param  {Vue}    vueElement    The Vue component in question
     * @param  {Mixed}  mapboxElement The Mapbox element bound to the component
     * @param  {Array}  events        The events to map
     * @param  {String} layerId       The layer on which the events are delegated
     * @return {Array}                The list of event/handler pair bounded
     */
    function bindEvents(vueElement, mapboxElement, events, layerId) {
        if (events === void 0) { events = []; }
        if (layerId === void 0) { layerId = null; }
        var vueEvents = vueElement.$listeners;
        // eslint-disable-next-line no-param-reassign
        vueElement.$$events = Object.keys(vueEvents).reduce(function ($$events, vueEvent) {
            var originalEvent = vueEvent.replace(/^mb-/, '');
            if (!events.includes(originalEvent)) {
                return $$events;
            }
            var handler = function () {
                var payload = [];
                for (var _i = 0; _i < arguments.length; _i++) {
                    payload[_i] = arguments[_i];
                }
                vueElement.$emit(vueEvent, payload);
            };
            // If layerId is not null, all events must be
            // delegated from the map to the given layerId
            if (layerId) {
                mapboxElement.on(originalEvent, layerId, handler);
            }
            else {
                mapboxElement.on(originalEvent, handler);
            }
            $$events.push([originalEvent, handler]);
            return $$events;
        }, []);
    }
    /**
     * Unbind events from the map element
     *
     * @param  {Mixed} mapboxElement The Mapbox element which needs unbinding
     * @param  {Array}  handlers     The list of event/handler pair to unbind
     * @param  {String} layerId      The layer on which the events where delegated
     * @return {void}
     */
    function unbindEvents(vueElement, mapboxElement, layerId) {
        if (layerId === void 0) { layerId = null; }
        vueElement.$$events.forEach(function (_a) {
            var event = _a[0], handler = _a[1];
            // If layerId is not null, all events must be
            // delegated from the map to the given layerId
            if (layerId) {
                mapboxElement.off(event, layerId, handler);
            }
            else {
                mapboxElement.off(event, handler);
            }
        });
    }

    if (!mapboxgl__default['default']) {
        throw new Error('mapboxgl is not installed.');
    }
    if (!MapboxGeocoder__default['default']) {
        throw new Error('MapboxGeocoder is not installed.');
    }
    /**
     ** Component's props definition, we need to declare it outside the component
     * to be able to test the default values and the types.
     * @see https://github.com/mapbox/mapbox-gl-geocoder/blob/master/API.md#parameters
     * @type {object}
     */
    var props = {
        accessToken: {
            type: String,
            default: 'no-token',
        },
        zoom: {
            type: Number,
            default: function () { return 16; },
        },
        flyTo: {
            type: Object,
            default: function () { return true; },
        },
        placeholder: {
            type: String,
            default: function () { return 'Search'; },
        },
        proximity: {
            type: Object,
            default: function () { },
        },
        trackProximity: {
            type: Boolean,
            default: function () { return true; },
        },
        collapsed: {
            type: Boolean,
            default: function () { return false; },
        },
        clearAndBlurOnEsc: {
            type: Boolean,
            default: function () { return false; },
        },
        clearOnBlur: {
            type: Boolean,
            default: function () { return false; },
        },
        bbox: {
            type: Array,
            default: function () { return []; },
        },
        countries: {
            type: String,
            default: function () { return ''; },
        },
        types: {
            type: String,
            default: function () { return ''; },
        },
        minLength: {
            type: Number,
            default: function () { return 2; },
        },
        limit: {
            type: Number,
            default: function () { return 5; },
        },
        language: {
            type: String,
        },
        filter: {
            type: Function,
        },
        localGeocoder: {
            type: Function,
        },
        reverseMode: {
            type: String,
            default: function () { return 'distance'; },
        },
        reverseGeocode: {
            type: Boolean,
            default: function () { return false; },
        },
        enableEventLogging: {
            type: Boolean,
            default: function () { return false; },
        },
        marker: {
            type: Boolean,
            default: function () { return true; },
        },
        render: {
            type: Function,
        },
        getItemValue: {
            type: Function,
            default: function (item) { return item.place_name; },
        },
        mode: {
            type: String,
            default: function () { return 'mapbox.places'; },
        },
        localGeocoderOnly: {
            type: Boolean,
            default: function () { return false; },
        },
    };
    /**
     * All Map events which will be mapped/bounded to the component
     * @see  https://github.com/mapbox/mapbox-gl-geocoder/blob/master/API.md#on
     * @type {Array}
     */
    var events = ['loading', 'results', 'result', 'error'];
    var script = mixins__default['default'](injectMap).extend({
        name: 'MapboxGeocoder',
        props: props,
        data: function () { return ({
            control: null
        }); },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map, _a, accessToken, $props;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _b.sent();
                            _a = this.$props, accessToken = _a.accessToken, $props = __rest(_a, ["accessToken"]);
                            // Delete the `reverseMode` property if we are not reverse geocoding as it is not supported by
                            // the Mapbox SDK.
                            //
                            // The `reverseMode` option can not be supported yet as it is conditionned by the search
                            // query format following a specific regex:
                            //
                            // ```js
                            //  /(-?\d+\.?\d*)[, ]+(-?\d+\.?\d*)[ ]*$/.test(searchInput)
                            // ```
                            //
                            // @todo use the same regex as the mapbox-gl-geocoder lib or open an issue
                            //
                            // @see https://github.com/mapbox/mapbox-sdk-js/blob/main/services/geocoding.js (92-104)
                            // @see https://github.com/mapbox/mapbox-sdk-js/blob/main/services/geocoding.js (161-172)
                            // @see https://github.com/mapbox/mapbox-gl-geocoder/blob/master/lib/index.js (437-458)
                            // eslint-disable-next-line no-constant-condition
                            if (!$props.reverseGeocode || true) {
                                delete $props.reverseMode;
                            }
                            this.control = new MapboxGeocoder__default['default'](__assign({ accessToken: mapboxgl__default['default'].accessToken || accessToken, mapboxgl: mapboxgl__default['default'] }, $props));
                            // Bind events
                            bindEvents(this, this.control, events);
                            this.$emit('mb-created', this.control);
                            if (this.control)
                                this.control.addTo(map || this.$el);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            unbindEvents(this, this.control);
                            if (map && this.control) {
                                map.removeControl(this.control);
                            }
                            return [2 /*return*/];
                    }
                });
            });
        },
    });

    function normalizeComponent(template, style, script, scopeId, isFunctionalTemplate, moduleIdentifier /* server only */, shadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
        if (typeof shadowMode !== 'boolean') {
            createInjectorSSR = createInjector;
            createInjector = shadowMode;
            shadowMode = false;
        }
        // Vue.extend constructor export interop.
        const options = typeof script === 'function' ? script.options : script;
        // render functions
        if (template && template.render) {
            options.render = template.render;
            options.staticRenderFns = template.staticRenderFns;
            options._compiled = true;
            // functional template
            if (isFunctionalTemplate) {
                options.functional = true;
            }
        }
        // scopedId
        if (scopeId) {
            options._scopeId = scopeId;
        }
        let hook;
        if (moduleIdentifier) {
            // server build
            hook = function (context) {
                // 2.3 injection
                context =
                    context || // cached call
                        (this.$vnode && this.$vnode.ssrContext) || // stateful
                        (this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext); // functional
                // 2.2 with runInNewContext: true
                if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
                    context = __VUE_SSR_CONTEXT__;
                }
                // inject component styles
                if (style) {
                    style.call(this, createInjectorSSR(context));
                }
                // register component module identifier for async chunk inference
                if (context && context._registeredComponents) {
                    context._registeredComponents.add(moduleIdentifier);
                }
            };
            // used by ssr in case component is cached and beforeCreate
            // never gets called
            options._ssrRegister = hook;
        }
        else if (style) {
            hook = shadowMode
                ? function (context) {
                    style.call(this, createInjectorShadow(context, this.$root.$options.shadowRoot));
                }
                : function (context) {
                    style.call(this, createInjector(context));
                };
        }
        if (hook) {
            if (options.functional) {
                // register for functional component in vue file
                const originalRender = options.render;
                options.render = function renderWithStyleInjection(h, context) {
                    hook.call(context);
                    return originalRender(h, context);
                };
            }
            else {
                // inject component registration as beforeCreate hook
                const existing = options.beforeCreate;
                options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
            }
        }
        return script;
    }

    /* script */
    const __vue_script__ = script;

    /* template */
    var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
    var __vue_staticRenderFns__ = [];

      /* style */
      const __vue_inject_styles__ = undefined;
      /* scoped */
      const __vue_scope_id__ = undefined;
      /* module identifier */
      const __vue_module_identifier__ = undefined;
      /* functional template */
      const __vue_is_functional_template__ = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__ = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
        __vue_inject_styles__,
        __vue_script__,
        __vue_scope_id__,
        __vue_is_functional_template__,
        __vue_module_identifier__,
        false,
        undefined,
        undefined,
        undefined
      );

    var script$1 = mixins__default['default'](injectMap).extend({
        name: 'MapboxImage',
        props: {
            /**
               * The ID of the image
               * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
               * @type {String}
               */
            id: {
                type: String,
                required: true,
            },
            /**
               * The image as String, an HTMLImageElement, ImageData, or object with
               * width, height, and data properties with the same format as ImageData.
               * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
               * @type {String|HTMLImageElement|ImageData|Object}
               */
            src: {
                type: Object,
                required: true,
            },
            /**
               * The options object for the image to add
               * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
               * @type {Object}
               */
            options: {
                type: Object,
                default: function () { return ({ pixelRatio: 1, sdf: false }); },
            },
        },
        data: function () {
            return {
                isReady: false,
            };
        },
        watch: {
            src: {
                handler: function (newValue) {
                    return __awaiter(this, void 0, void 0, function () {
                        var map;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0: return [4 /*yield*/, this.map.promise];
                                case 1:
                                    map = _a.sent();
                                    map.updateImage(this.id, newValue);
                                    return [2 /*return*/];
                            }
                        });
                    });
                },
                deep: true,
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map, _a, id, src, options, image;
                return __generator(this, function (_b) {
                    switch (_b.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _b.sent();
                            _a = this, id = _a.id, src = _a.src, options = _a.options;
                            // If source is not a string, we don't need to load the image and we can
                            // add it to the map directly.
                            if (typeof src !== 'string') {
                                map.addImage(id, src, options);
                                this.$emit('add', { id: id, src: src, options: options });
                                this.isReady = true;
                                return [2 /*return*/];
                            }
                            return [4 /*yield*/, this.loadImage(src)];
                        case 2:
                            image = _b.sent();
                            map.addImage(id, image, options);
                            this.$emit('add', { id: id, src: image, options: options });
                            this.isReady = true;
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            if (map.hasImage(this.id)) {
                                map.removeImage(this.id);
                            }
                            return [2 /*return*/];
                    }
                });
            });
        },
        methods: {
            /**
               * Load the given image with the Mapbox `loadImage` method
               *
               * @param  {String}  src The source URL for the image
               * @return {Promise}     A promise which will resolve on load
               */
            loadImage: function (src) {
                return __awaiter(this, void 0, void 0, function () {
                    var _this = this;
                    return __generator(this, function (_a) {
                        return [2 /*return*/, new Promise(function (resolve, reject) { return __awaiter(_this, void 0, void 0, function () {
                                var map;
                                return __generator(this, function (_a) {
                                    switch (_a.label) {
                                        case 0: return [4 /*yield*/, this.map.promise];
                                        case 1:
                                            map = _a.sent();
                                            map.loadImage(src, function (err, data) {
                                                if (err || !data) {
                                                    return reject(err);
                                                }
                                                return resolve(data);
                                            });
                                            return [2 /*return*/];
                                    }
                                });
                            }); })];
                    });
                });
            },
        },
    });

    /* script */
    const __vue_script__$1 = script$1;

    /* template */
    var __vue_render__$1 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{attrs:{"id":_vm.id}},[(_vm.isReady)?_vm._t("default"):_vm._e()],2)};
    var __vue_staticRenderFns__$1 = [];

      /* style */
      const __vue_inject_styles__$1 = undefined;
      /* scoped */
      const __vue_scope_id__$1 = undefined;
      /* module identifier */
      const __vue_module_identifier__$1 = undefined;
      /* functional template */
      const __vue_is_functional_template__$1 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$1 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$1, staticRenderFns: __vue_staticRenderFns__$1 },
        __vue_inject_styles__$1,
        __vue_script__$1,
        __vue_scope_id__$1,
        __vue_is_functional_template__$1,
        __vue_module_identifier__$1,
        false,
        undefined,
        undefined,
        undefined
      );

    var script$2 = mixins__default['default']().extend({
        name: 'MapboxImages',
        components: {
            MapboxImage: __vue_component__$1,
        },
        props: {
            /**
             * A list of sources to add to the map
             * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
             * @see  ./MapboxImage.vue
             * @type {Object}
             */
            sources: {
                type: Array,
                required: true,
            },
        },
        data: function () { return ({
            isReady: false,
            addedImages: new Map(),
        }); },
        methods: {
            addHandler: function (image, index, total) {
                if (!this.addedImages.has(image.id)) {
                    this.addedImages.set(image.id, image);
                    this.$emit('add', image, index, total);
                }
                if (this.addedImages.size === this.sources.length) {
                    this.isReady = true;
                    this.$emit('ready', this.addedImages.values());
                }
            },
        },
    });

    /* script */
    const __vue_script__$2 = script$2;

    /* template */
    var __vue_render__$2 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_vm._l((_vm.sources),function(source,index){return _c('mapbox-image',_vm._b({key:("mapbox-images-" + (source.id)),on:{"add":function($event){return _vm.addHandler($event, index + 1, _vm.sources.length)}}},'mapbox-image',source,false))}),_vm._v(" "),(_vm.isReady)?_vm._t("default"):_vm._e()],2)};
    var __vue_staticRenderFns__$2 = [];

      /* style */
      const __vue_inject_styles__$2 = undefined;
      /* scoped */
      const __vue_scope_id__$2 = undefined;
      /* module identifier */
      const __vue_module_identifier__$2 = undefined;
      /* functional template */
      const __vue_is_functional_template__$2 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$2 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$2, staticRenderFns: __vue_staticRenderFns__$2 },
        __vue_inject_styles__$2,
        __vue_script__$2,
        __vue_scope_id__$2,
        __vue_is_functional_template__$2,
        __vue_module_identifier__$2,
        false,
        undefined,
        undefined,
        undefined
      );

    /**
     * All Map events which will be mapped/bounded to the component
     * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#on
     * @type {Array}
     */
    var events$1 = [
        'mousedown',
        'mouseup',
        'click',
        'dblclick',
        'mousemove',
        'mouseenter',
        'mouseleave',
        'mouseover',
        'mouseout',
        'contextmenu',
        'touchstart',
        'touchend',
        'touchcancel',
    ];
    var script$3 = mixins__default['default'](injectMap).extend({
        name: 'MapboxLayer',
        props: {
            /**
             * Id of the layer
             * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addlayer
             * @type {String}
             */
            id: {
                type: String,
                required: true,
            },
            /**
             * Options for the layer
             * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addlayer
             * @see  https://docs.mapbox.com/mapbox-gl-js/style-spec/#layers
             * @type {Object}
             */
            options: {
                type: Object,
                default: function () { },
            },
            /**
             * The ID of an existing layer to insert the new layer before.
             * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addlayer
             * @type {String}
             */
            beforeId: {
                type: String,
                default: undefined,
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            if (this.layerExists()) {
                                map.removeLayer(this.id);
                            }
                            if (this.sourceExists()) {
                                map.removeSource(this.id);
                            }
                            // Bind events
                            bindEvents(this, this.map, events$1, this.id);
                            if (this.options.paint === null || this.options.paint === undefined) {
                                delete this.options.paint;
                            }
                            if (this.options.layout === null || this.options.layout === undefined) {
                                delete this.options.layout;
                            }
                            map.addLayer(__assign(__assign({}, this.options), { id: this.id }), this.beforeId);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            if (this.layerExists()) {
                                unbindEvents(this, this.map, this.id);
                                map.removeLayer(this.id);
                            }
                            if (this.sourceExists()) {
                                map.removeSource(this.id);
                            }
                            return [2 /*return*/];
                    }
                });
            });
        },
        methods: {
            /**
             * Test if the component's layer exists
             * @return {Boolean}
             */
            layerExists: function () {
                return __awaiter(this, void 0, void 0, function () {
                    var map;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, this.map.promise];
                            case 1:
                                map = _a.sent();
                                return [2 /*return*/, typeof map.getLayer(this.id) !== 'undefined'];
                        }
                    });
                });
            },
            /**
             * Test if a source with the layer's ID exists
             * @return {Boolean}
             */
            sourceExists: function () {
                return __awaiter(this, void 0, void 0, function () {
                    var map;
                    return __generator(this, function (_a) {
                        switch (_a.label) {
                            case 0: return [4 /*yield*/, this.map.promise];
                            case 1:
                                map = _a.sent();
                                return [2 /*return*/, typeof map.getSource(this.id) !== 'undefined'];
                        }
                    });
                });
            },
        },
    });

    /* script */
    const __vue_script__$3 = script$3;

    /* template */
    var __vue_render__$3 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{attrs:{"id":_vm.id}})};
    var __vue_staticRenderFns__$3 = [];

      /* style */
      const __vue_inject_styles__$3 = undefined;
      /* scoped */
      const __vue_scope_id__$3 = undefined;
      /* module identifier */
      const __vue_module_identifier__$3 = undefined;
      /* functional template */
      const __vue_is_functional_template__$3 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$3 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$3, staticRenderFns: __vue_staticRenderFns__$3 },
        __vue_inject_styles__$3,
        __vue_script__$3,
        __vue_scope_id__$3,
        __vue_is_functional_template__$3,
        __vue_module_identifier__$3,
        false,
        undefined,
        undefined,
        undefined
      );

    /**
     * Capitalize the first letter of a string
     *
     * @param  {String} string The string to capitalize
     * @return {String}        The capitalized string
     */
    function capitalizeFirstLetter(string) {
        return string.charAt(0).toUpperCase() + string.slice(1);
    }
    /**
     * Automatically set a mapbox element's props when the vue element props changes
     *
     * @param  {Vue}    vueElement    The Vue component in question
     * @param  {Mixed}  mapboxElement The Mapbox element bound to the component
     * @param  {Object} props         The component's props definition object
     * @return {void}
     */
    function bindProps(vueElement, mapboxElement, props) {
        Object.keys(vueElement.$props)
            .filter(function (prop) { return prop !== undefined; })
            .forEach(function (prop) {
            var setMethodName = prop === 'mapStyle' ? 'setStyle' : "set" + capitalizeFirstLetter(prop);
            var methodExists = typeof mapboxElement[setMethodName] === 'function';
            var propNeedsBinding = 'bind' in props[prop] ? props[prop].bind : true;
            // Do nothin if `setMethodName` is not a function of `mapBoxElement`
            // or if the props is not to be bounded
            if (!methodExists || !propNeedsBinding) {
                return;
            }
            // Set deep option to true if prop type is or can be Object
            var type = props[prop].type;
            var options = {
                deep: type === Object || (Array.isArray(type) && type.includes(Object)),
            };
            vueElement.$watch(prop, function (newValue) {
                mapboxElement[setMethodName](newValue);
            }, options);
        });
    }

    var provideMap = mixins__default['default']().extend({
        data: function () { return ({
            static: Object.freeze({
                map: new Deferred__default['default'](),
            }),
        }); },
        provide: function () {
            var _this = this;
            return {
                $map: function () { return _this.static.map; }
            };
        },
    });

    if (!mapboxgl__default['default']) {
        throw new Error('mapboxgl is not installed.');
    }
    /**
       * Component's props definition, we need to declare it outside the component
       * to be able to test the default values and the types.
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map
       * @type {Object}
       */
    /**
       * All Map events which will be mapped/bounded to the component
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map.event:resize
       * @type {Array}
       */
    var events$2 = [
        'resize',
        'remove',
        'mousedown',
        'mouseup',
        'mouseover',
        'mousemove',
        'click',
        'dblclick',
        'mouseenter',
        'mouseleave',
        'mouseout',
        'contextmenu',
        'wheel',
        'touchstart',
        'touchend',
        'touchmove',
        'touchcancel',
        'movestart',
        'move',
        'moveend',
        'dragstart',
        'drag',
        'dragend',
        'zoomstart',
        'zoom',
        'zoomend',
        'rotatestart',
        'rotate',
        'rotateend',
        'pitchstart',
        'pitch',
        'pitchend',
        'boxzoomstart',
        'boxzoomend',
        'boxzoomcancel',
        'webglcontextlost',
        'webglcontextrestored',
        'load',
        'render',
        'idle',
        'error',
        'data',
        'styledata',
        'sourcedata',
        'dataloading',
        'styledataloading',
        'sourcedataloading',
        'styleimagemissing',
    ];
    var script$4 = mixins__default['default'](provideMap).extend({
        name: 'MapboxMap',
        props: {
            accessToken: {
                type: String,
                default: 'no-token',
            },
            container: {
                type: Object || String,
                default: '',
            },
            minZoom: {
                type: Number,
                default: 0,
            },
            maxZoom: {
                type: Number,
                default: 22,
            },
            minPitch: {
                type: Number,
                default: 0,
            },
            maxPitch: {
                type: Number,
                default: 60,
            },
            mapStyle: {
                type: Object,
                required: true,
            },
            hash: {
                type: Boolean,
                default: false,
            },
            interactive: {
                type: Boolean,
                default: true,
            },
            bearingSnap: {
                type: Number,
                default: 7,
            },
            pitchWithRotate: {
                type: Boolean,
                default: true,
            },
            clickTolerance: {
                type: Number,
                default: 3,
            },
            attributionControl: {
                type: Boolean,
                default: true,
            },
            customAttribution: {
                type: Array,
                default: null,
            },
            logoPosition: {
                type: String,
                default: 'bottom-left',
            },
            failIfMajorPerformanceCaveat: {
                type: Boolean,
                default: false,
            },
            preserveDrawingBuffer: {
                type: Boolean,
                default: false,
            },
            antialias: {
                type: Boolean,
                default: false,
            },
            refreshExpiredTiles: {
                type: Boolean,
                default: true,
            },
            maxBounds: {
                type: Array,
                default: undefined,
            },
            scrollZoom: {
                type: [Boolean, Object],
                default: true,
            },
            boxZoom: {
                type: Boolean,
                default: true,
            },
            dragRotate: {
                type: Boolean,
                default: true,
            },
            dragPan: {
                type: Object,
                default: true,
            },
            keyboard: {
                type: Boolean,
                default: true,
            },
            doubleClickZoom: {
                type: Boolean,
                default: true,
            },
            touchZoomRotate: {
                type: Object,
                default: true,
            },
            trackResize: {
                type: Boolean,
                default: true,
            },
            center: {
                type: Object,
                default: function () { return [0, 0]; },
            },
            zoom: {
                type: Number,
                default: 0,
            },
            bearing: {
                type: Number,
                default: 0,
            },
            pitch: {
                type: Number,
                default: 0,
            },
            bounds: {
                type: Array,
                default: undefined,
            },
            fitBoundsOptions: {
                type: Object,
                default: null,
            },
            renderWorldCopies: {
                type: Boolean,
                default: true,
            },
            maxTileCacheSize: {
                type: Number,
                default: null,
            },
            localIdeographFontFamily: {
                type: String,
                default: 'sans-serif',
            },
            transformRequest: {
                type: Function,
                default: null,
            },
            collectResourceTiming: {
                type: Boolean,
                default: false,
            },
            fadeDuration: {
                type: Number,
                default: 300,
            },
            crossSourceCollisions: {
                type: Boolean,
                default: true,
            },
        },
        data: function () { return ({
            isLoaded: false,
            resizeObserver: null
        }); },
        computed: {
            options: function () {
                // eslint-disable-next-line no-unused-vars
                var _a = this.$props, accessToken = _a.accessToken, style = _a.mapStyle, options = __rest(_a, ["accessToken", "mapStyle"]);
                // Use current component's element if container is not set
                if (!options.container && this.$el) {
                    options.container = this.$el;
                }
                return __assign({ style: style }, options);
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map, observer;
                var _this = this;
                return __generator(this, function (_a) {
                    mapboxgl__default['default'].accessToken = this.accessToken;
                    map = new mapboxgl__default['default'].Map(this.options);
                    map.on('load', function () {
                        _this.static.map.resolve(map);
                        _this.isLoaded = true;
                    });
                    // Bind props and events
                    bindProps(this, map, this.$props);
                    bindEvents(this, map, events$2);
                    this.$emit('mb-created', map);
                    observer = new ResizeObserver(this.resizeHandler);
                    observer.observe(this.options.container);
                    this.resizeObserver = observer;
                    return [2 /*return*/];
                });
            });
        },
        destroyed: function () {
            unbindEvents(this, this.static.map.val);
            if (this.resizeObserver)
                this.resizeObserver.disconnect();
            if (this.static.map.val)
                this.static.map.val.remove();
        },
        methods: {
            resizeHandler: function () {
                if (this.static.map.val) {
                    this.static.map.val.resize();
                }
            },
        },
    });

    /* script */
    const __vue_script__$4 = script$4;

    /* template */
    var __vue_render__$4 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[(_vm.isLoaded)?_c('div',[_vm._t("default")],2):_c('div',[_vm._t("loader")],2)])};
    var __vue_staticRenderFns__$4 = [];

      /* style */
      const __vue_inject_styles__$4 = undefined;
      /* scoped */
      const __vue_scope_id__$4 = undefined;
      /* module identifier */
      const __vue_module_identifier__$4 = undefined;
      /* functional template */
      const __vue_is_functional_template__$4 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$4 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$4, staticRenderFns: __vue_staticRenderFns__$4 },
        __vue_inject_styles__$4,
        __vue_script__$4,
        __vue_scope_id__$4,
        __vue_is_functional_template__$4,
        __vue_module_identifier__$4,
        false,
        undefined,
        undefined,
        undefined
      );

    /**
       * Component's props definition, we need to declare it outside the component
       * to be able to test the default values and the types.
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#popup
       * @type {Object}
       */
    var props$1 = {
        lngLat: {
            type: Object,
            required: true,
        },
        closeButton: {
            type: Boolean,
            default: true,
        },
        closeOnClick: {
            type: Boolean,
            default: true,
        },
        closeOnMove: {
            type: Boolean,
            default: false,
        },
        anchor: {
            type: String,
            default: null,
        },
        offset: {
            type: Object,
            default: null,
        },
        className: {
            type: String,
            default: null,
        },
        maxWidth: {
            type: String,
            default: '240px',
        },
        /**
           * Do not render the popup on the map.
           * @type {Object}
           */
        renderless: {
            type: Boolean,
            default: false,
            bind: false,
        },
    };
    /**
       * All Map events which will be mapped/bounded to the component
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#popup.event:open
       * @type {Array}
       */
    var events$3 = ['open', 'close'];
    var script$5 = mixins__default['default'](injectMap).extend({
        name: 'MapboxPopup',
        props: props$1,
        data: function () { return ({
            popup: null
        }); },
        computed: {
            options: function () {
                // eslint-disable-next-line no-unused-vars
                var _a = this.$props, lngLat = _a.lngLat, options = __rest(_a, ["lngLat"]);
                return options;
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            this.popup = new mapboxgl.Popup(this.options)
                                .setLngLat(this.lngLat)
                                .setDOMContent(this.$el);
                            if (!this.renderless) {
                                this.popup.addTo(map);
                            }
                            bindProps(this, this.popup, props$1);
                            bindEvents(this, this.popup, events$3);
                            this.$emit('mb-open', this.popup);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            if (this.popup) {
                unbindEvents(this, this.popup);
                this.popup.remove();
            }
        },
    });

    /* script */
    const __vue_script__$5 = script$5;

    /* template */
    var __vue_render__$5 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_vm._t("default")],2)};
    var __vue_staticRenderFns__$5 = [];

      /* style */
      const __vue_inject_styles__$5 = undefined;
      /* scoped */
      const __vue_scope_id__$5 = undefined;
      /* module identifier */
      const __vue_module_identifier__$5 = undefined;
      /* functional template */
      const __vue_is_functional_template__$5 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$5 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$5, staticRenderFns: __vue_staticRenderFns__$5 },
        __vue_inject_styles__$5,
        __vue_script__$5,
        __vue_scope_id__$5,
        __vue_is_functional_template__$5,
        __vue_module_identifier__$5,
        false,
        undefined,
        undefined,
        undefined
      );

    /**
       * Component's props definition, we need to declare it outside the component
       * to be able to test the default values and the types.
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#marker
       * @type {Object}
       */
    var props$2 = {
        lngLat: {
            // type: Array as () => Array<number>,
            default: [0, 0],
            required: true,
        },
        popup: {
            type: Object,
            default: false,
            bind: false,
        },
        element: {
            type: HTMLElement,
            default: null,
        },
        offset: {
            type: Array,
            default: [0, 0],
        },
        anchor: {
            type: String,
            default: 'center',
        },
        color: {
            type: String,
            default: null,
        },
        scale: {
            type: Number,
            default: 1,
        },
        draggable: {
            type: Boolean,
            default: false,
        },
        rotation: {
            type: Number,
            default: 0,
        },
        pitchAlignment: {
            type: String,
            default: 'auto',
        },
        rotationAlignment: {
            type: String,
            default: 'auto',
        },
    };
    /**
       * All Map events which will be mapped/bounded to the component
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#marker.event:dragstart
       * @type {Array}
       */
    var events$4 = ['dragstart', 'drag', 'dragend'];
    var script$6 = mixins__default['default'](injectMap).extend({
        name: 'MapboxMarker',
        components: {
            MapboxPopup: __vue_component__$5,
        },
        props: props$2,
        data: function () { return ({
            marker: null
        }); },
        computed: {
            hasPopup: function () {
                return this.popup !== false && this.$refs.popup !== undefined;
            },
            popupInstance: function () {
                return this.hasPopup ? this.$refs.popup.popup : null;
            },
            popupOptions: function () {
                if (typeof this.popup === 'object') {
                    return __assign(__assign({ lngLat: this.lngLat }, this.popup), { renderless: true });
                }
                else
                    return null;
            },
            options: function () {
                // eslint-disable-next-line no-unused-vars
                var _a = this.$props, lngLat = _a.lngLat, popup = _a.popup, options = __rest(_a, ["lngLat", "popup"]);
                // Use current component's element if container is not set
                if (this.$slots.default) {
                    options.element = this.$refs.content;
                }
                return options;
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            this.marker = new mapboxgl.Marker(this.options)
                                .setLngLat(this.lngLat)
                                .addTo(map);
                            // Bind props and events
                            bindProps(this, this.marker, props$2);
                            bindEvents(this, this.marker, events$4);
                            if (this.hasPopup && this.popupInstance) {
                                this.marker.setPopup(this.popupInstance);
                            }
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            if (this.marker) {
                unbindEvents(this, this.marker);
                this.marker.remove();
            }
        },
    });

    /* script */
    const __vue_script__$6 = script$6;

    /* template */
    var __vue_render__$6 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',[_c('div',{ref:"content"},[_vm._t("default")],2),_vm._v(" "),(_vm.popup)?_c('mapbox-popup',_vm._b({ref:"popup"},'mapbox-popup',_vm.popupOptions,false),[_vm._t("popup")],2):_vm._e()],1)};
    var __vue_staticRenderFns__$6 = [];

      /* style */
      const __vue_inject_styles__$6 = undefined;
      /* scoped */
      const __vue_scope_id__$6 = undefined;
      /* module identifier */
      const __vue_module_identifier__$6 = undefined;
      /* functional template */
      const __vue_is_functional_template__$6 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$6 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$6, staticRenderFns: __vue_staticRenderFns__$6 },
        __vue_inject_styles__$6,
        __vue_script__$6,
        __vue_scope_id__$6,
        __vue_is_functional_template__$6,
        __vue_module_identifier__$6,
        false,
        undefined,
        undefined,
        undefined
      );

    /**
       * Component's props definition, we need to declare it outside the component
       * to be able to test the default values and the types.
       * @type {Object}
       */
    var props$3 = {
        showCompass: {
            type: Boolean,
            default: true,
        },
        showZoom: {
            type: Boolean,
            default: true,
        },
        visualizePitch: {
            type: Boolean,
            default: false,
        },
        position: {
            type: String,
            default: function () { return 'top-right'; },
            bind: false,
        },
    };
    var script$7 = mixins__default['default'](injectMap).extend({
        name: 'MapboxNavigationControl',
        props: props$3,
        data: function () { return ({
            control: null
        }); },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            this.control = new mapboxgl.NavigationControl(this.$props);
                            bindProps(this, this.control, props$3);
                            map.addControl(this.control, this.position);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            if (this.control)
                                map.removeControl(this.control);
                            return [2 /*return*/];
                    }
                });
            });
        },
    });

    /* script */
    const __vue_script__$7 = script$7;

    /* template */
    var __vue_render__$7 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
    var __vue_staticRenderFns__$7 = [];

      /* style */
      const __vue_inject_styles__$7 = undefined;
      /* scoped */
      const __vue_scope_id__$7 = undefined;
      /* module identifier */
      const __vue_module_identifier__$7 = undefined;
      /* functional template */
      const __vue_is_functional_template__$7 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$7 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$7, staticRenderFns: __vue_staticRenderFns__$7 },
        __vue_inject_styles__$7,
        __vue_script__$7,
        __vue_scope_id__$7,
        __vue_is_functional_template__$7,
        __vue_module_identifier__$7,
        false,
        undefined,
        undefined,
        undefined
      );

    var script$8 = mixins__default['default'](injectMap).extend({
        name: 'MapboxSource',
        props: {
            options: {
                type: Object,
                default: null
            },
            id: {
                type: String,
                required: true,
            },
        },
        watch: {
            'options.data': function (newData) {
                var map = this.map.val;
                if (map)
                    map.getSource(this.id).setData(newData);
            },
        },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            if (this.options)
                                map.addSource(this.id, this.options);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map, layers;
                var _this = this;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            layers = map.getStyle().layers;
                            if (layers)
                                Object.values(layers).forEach(function (value) {
                                    if (value.source && value.source === _this.id) {
                                        map.removeLayer(value.id);
                                    }
                                });
                            // And remove the source
                            map.removeSource(this.id);
                            return [2 /*return*/];
                    }
                });
            });
        },
    });

    /* script */
    const __vue_script__$8 = script$8;

    /* template */
    var __vue_render__$8 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div',{attrs:{"id":_vm.id}})};
    var __vue_staticRenderFns__$8 = [];

      /* style */
      const __vue_inject_styles__$8 = undefined;
      /* scoped */
      const __vue_scope_id__$8 = undefined;
      /* module identifier */
      const __vue_module_identifier__$8 = undefined;
      /* functional template */
      const __vue_is_functional_template__$8 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$8 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$8, staticRenderFns: __vue_staticRenderFns__$8 },
        __vue_inject_styles__$8,
        __vue_script__$8,
        __vue_scope_id__$8,
        __vue_is_functional_template__$8,
        __vue_module_identifier__$8,
        false,
        undefined,
        undefined,
        undefined
      );

    if (!mapboxgl__default['default']) {
        throw new Error('mapboxgl is not installed.');
    }
    /**
       * Component's props definition, we need to declare it outside the component
       * to be able to test the default values and the types.
       * @see https://docs.mapbox.com/mapbox-gl-js/api/#geolocatecontrol
       * @type {Object}
       */
    var props$4 = {
        positionOptions: {
            type: Object,
            default: function () { return ({ enableHighAccuracy: false, timeout: 6000 }); },
        },
        fitBoundsOptions: {
            type: Object,
            default: function () { return ({ maxZoom: 15 }); },
        },
        trackUserLocation: {
            type: Boolean,
            default: false,
        },
        showAccuracyCircle: {
            type: Boolean,
            default: true,
        },
        showUserLocation: {
            type: Boolean,
            default: true,
        },
        position: {
            type: String,
            default: function () { return 'top-right'; },
            bind: false,
        },
    };
    /**
       * All geolocationControl events which will be mapped/bounded to the component
       * @see https://docs.mapbox.com/mapbox-gl-js/api/#geolocatecontrol.event:trackuserlocationend
       * @type {Array}
       */
    var events$5 = [
        'trackuserlocationend',
        'error',
        'geolocate',
        'outofmaxbounds',
        'trackuserlocationstart',
    ];
    var script$9 = mixins__default['default'](injectMap).extend({
        name: 'MapboxGeolocateControl',
        props: props$4,
        data: function () { return ({
            control: null
        }); },
        mounted: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0: return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            this.control = new mapboxgl__default['default'].GeolocateControl(this.$props);
                            // Bind props and events
                            bindProps(this, this.control, props$4);
                            bindEvents(this, this.control, events$5);
                            // Add GeolocationControl to the map
                            map.addControl(this.control, this.position);
                            return [2 /*return*/];
                    }
                });
            });
        },
        destroyed: function () {
            return __awaiter(this, void 0, void 0, function () {
                var map;
                return __generator(this, function (_a) {
                    switch (_a.label) {
                        case 0:
                            if (!this.control) return [3 /*break*/, 2];
                            return [4 /*yield*/, this.map.promise];
                        case 1:
                            map = _a.sent();
                            unbindEvents(this, this.control, events$5);
                            map.removeControl(this.control);
                            _a.label = 2;
                        case 2: return [2 /*return*/];
                    }
                });
            });
        },
    });

    /* script */
    const __vue_script__$9 = script$9;

    /* template */
    var __vue_render__$9 = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return _c('div')};
    var __vue_staticRenderFns__$9 = [];

      /* style */
      const __vue_inject_styles__$9 = undefined;
      /* scoped */
      const __vue_scope_id__$9 = undefined;
      /* module identifier */
      const __vue_module_identifier__$9 = undefined;
      /* functional template */
      const __vue_is_functional_template__$9 = false;
      /* style inject */
      
      /* style inject SSR */
      
      /* style inject shadow dom */
      

      
      const __vue_component__$9 = /*#__PURE__*/normalizeComponent(
        { render: __vue_render__$9, staticRenderFns: __vue_staticRenderFns__$9 },
        __vue_inject_styles__$9,
        __vue_script__$9,
        __vue_scope_id__$9,
        __vue_is_functional_template__$9,
        __vue_module_identifier__$9,
        false,
        undefined,
        undefined,
        undefined
      );

    var components = {
        MapboxGeocoder: __vue_component__,
        MapboxImage: __vue_component__$1,
        MapboxImages: __vue_component__$2,
        MapboxLayer: __vue_component__$3,
        MapboxMap: __vue_component__$4,
        MapboxMarker: __vue_component__$6,
        MapboxNavigationControl: __vue_component__$7,
        MapboxPopup: __vue_component__$5,
        MapboxSource: __vue_component__$8,
        MapboxGeolocateControl: __vue_component__$9
    };

    /**
     * Install all components
     *
     * @param  {Vue}  Vue The Vue object
     * @return {void}
     */
    function install(Vue) {
        Object.keys(components).forEach(function (name) {
            Vue.component(name, components[name]);
        });
    }

    exports.MapboxGeocoder = __vue_component__;
    exports.MapboxGeolocateControl = __vue_component__$9;
    exports.MapboxImage = __vue_component__$1;
    exports.MapboxImages = __vue_component__$2;
    exports.MapboxLayer = __vue_component__$3;
    exports.MapboxMap = __vue_component__$4;
    exports.MapboxMarker = __vue_component__$6;
    exports.MapboxNavigationControl = __vue_component__$7;
    exports.MapboxPopup = __vue_component__$5;
    exports.MapboxSource = __vue_component__$8;
    exports.default = install;
    exports.install = install;

    Object.defineProperty(exports, '__esModule', { value: true });

})));
//# sourceMappingURL=VueMapboxGl.umd.min.js.map
