import { _ as __awaiter, a as __generator, n as normalizeComponent } from '../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import mapboxgl from 'mapbox-gl';
import injectMap from '../mixins/injectMap.ts';
import { bindEvents, unbindEvents } from '../utils/bind-events.ts';
import bindProps from '../utils/bind-props.ts';

if (!mapboxgl) {
  throw new Error('mapboxgl is not installed.');
}
/**
   * Component's props definition, we need to declare it outside the component
   * to be able to test the default values and the types.
   * @see https://docs.mapbox.com/mapbox-gl-js/api/#geolocatecontrol
   * @type {Object}
   */


var props = {
  positionOptions: {
    type: Object,
    default: function _default() {
      return {
        enableHighAccuracy: false,
        timeout: 6000
      };
    }
  },
  fitBoundsOptions: {
    type: Object,
    default: function _default() {
      return {
        maxZoom: 15
      };
    }
  },
  trackUserLocation: {
    type: Boolean,
    default: false
  },
  showAccuracyCircle: {
    type: Boolean,
    default: true
  },
  showUserLocation: {
    type: Boolean,
    default: true
  },
  position: {
    type: String,
    default: function _default() {
      return 'top-right';
    },
    bind: false
  }
};
/**
   * All geolocationControl events which will be mapped/bounded to the component
   * @see https://docs.mapbox.com/mapbox-gl-js/api/#geolocatecontrol.event:trackuserlocationend
   * @type {Array}
   */

var events = ['trackuserlocationend', 'error', 'geolocate', 'outofmaxbounds', 'trackuserlocationstart'];
var script = mixins(injectMap).extend({
  name: 'MapboxGeolocateControl',
  props: props,
  data: function data() {
    return {
      control: null
    };
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _a.sent();
            this.control = new mapboxgl.GeolocateControl(this.$props); // Bind props and events

            bindProps(this, this.control, props);
            bindEvents(this, this.control, events); // Add GeolocationControl to the map

            map.addControl(this.control, this.position);
            return [2
            /*return*/
            ];
        }
      });
    });
  },
  destroyed: function destroyed() {
    return __awaiter(this, void 0, void 0, function () {
      var map;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            if (!this.control) return [3
            /*break*/
            , 2];
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _a.sent();
            unbindEvents(this, this.control, events);
            map.removeControl(this.control);
            _a.label = 2;

          case 2:
            return [2
            /*return*/
            ];
        }
      });
    });
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div');
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxGeolocateControl.ts.map
