import { _ as __awaiter, a as __generator, n as normalizeComponent } from '../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import injectMap from '../mixins/injectMap.ts';

var script = mixins(injectMap).extend({
  name: 'MapboxImage',
  props: {
    /**
       * The ID of the image
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
       * @type {String}
       */
    id: {
      type: String,
      required: true
    },

    /**
       * The image as String, an HTMLImageElement, ImageData, or object with
       * width, height, and data properties with the same format as ImageData.
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
       * @type {String|HTMLImageElement|ImageData|Object}
       */
    src: {
      type: Object,
      required: true
    },

    /**
       * The options object for the image to add
       * @see  https://docs.mapbox.com/mapbox-gl-js/api/#map#addimage
       * @type {Object}
       */
    options: {
      type: Object,
      default: function _default() {
        return {
          pixelRatio: 1,
          sdf: false
        };
      }
    }
  },
  data: function data() {
    return {
      isReady: false
    };
  },
  watch: {
    src: {
      handler: function handler(newValue) {
        return __awaiter(this, void 0, void 0, function () {
          var map;
          return __generator(this, function (_a) {
            switch (_a.label) {
              case 0:
                return [4
                /*yield*/
                , this.map.promise];

              case 1:
                map = _a.sent();
                map.updateImage(this.id, newValue);
                return [2
                /*return*/
                ];
            }
          });
        });
      },
      deep: true
    }
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map, _a, id, src, options, image;

      return __generator(this, function (_b) {
        switch (_b.label) {
          case 0:
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _b.sent();
            _a = this, id = _a.id, src = _a.src, options = _a.options; // If source is not a string, we don't need to load the image and we can
            // add it to the map directly.

            if (typeof src !== 'string') {
              map.addImage(id, src, options);
              this.$emit('add', {
                id: id,
                src: src,
                options: options
              });
              this.isReady = true;
              return [2
              /*return*/
              ];
            }

            return [4
            /*yield*/
            , this.loadImage(src)];

          case 2:
            image = _b.sent();
            map.addImage(id, image, options);
            this.$emit('add', {
              id: id,
              src: image,
              options: options
            });
            this.isReady = true;
            return [2
            /*return*/
            ];
        }
      });
    });
  },
  destroyed: function destroyed() {
    return __awaiter(this, void 0, void 0, function () {
      var map;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _a.sent();

            if (map.hasImage(this.id)) {
              map.removeImage(this.id);
            }

            return [2
            /*return*/
            ];
        }
      });
    });
  },
  methods: {
    /**
       * Load the given image with the Mapbox `loadImage` method
       *
       * @param  {String}  src The source URL for the image
       * @return {Promise}     A promise which will resolve on load
       */
    loadImage: function loadImage(src) {
      return __awaiter(this, void 0, void 0, function () {
        var _this = this;

        return __generator(this, function (_a) {
          return [2
          /*return*/
          , new Promise(function (resolve, reject) {
            return __awaiter(_this, void 0, void 0, function () {
              var map;
              return __generator(this, function (_a) {
                switch (_a.label) {
                  case 0:
                    return [4
                    /*yield*/
                    , this.map.promise];

                  case 1:
                    map = _a.sent();
                    map.loadImage(src, function (err, data) {
                      if (err || !data) {
                        return reject(err);
                      }

                      return resolve(data);
                    });
                    return [2
                    /*return*/
                    ];
                }
              });
            });
          })];
        });
      });
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    attrs: {
      "id": _vm.id
    }
  }, [_vm.isReady ? _vm._t("default") : _vm._e()], 2);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxImage.ts.map
