import { c as __assign, b as __rest, _ as __awaiter, a as __generator, n as normalizeComponent } from '../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import { Marker } from 'mapbox-gl';
import injectMap from '../mixins/injectMap.ts';
import { unbindEvents, bindEvents } from '../utils/bind-events.ts';
import bindProps from '../utils/bind-props.ts';
import __vue_component__$1 from './MapboxPopup.ts';

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

/**
   * Component's props definition, we need to declare it outside the component
   * to be able to test the default values and the types.
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#marker
   * @type {Object}
   */

var props = {
  lngLat: {
    // type: Array as () => Array<number>,
    default: [0, 0],
    required: true
  },
  popup: {
    type: Object,
    default: false,
    bind: false
  },
  element: {
    type: HTMLElement,
    default: null
  },
  offset: {
    type: Array,
    default: [0, 0]
  },
  anchor: {
    type: String,
    default: 'center'
  },
  color: {
    type: String,
    default: null
  },
  scale: {
    type: Number,
    default: 1
  },
  draggable: {
    type: Boolean,
    default: false
  },
  rotation: {
    type: Number,
    default: 0
  },
  pitchAlignment: {
    type: String,
    default: 'auto'
  },
  rotationAlignment: {
    type: String,
    default: 'auto'
  }
};
/**
   * All Map events which will be mapped/bounded to the component
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#marker.event:dragstart
   * @type {Array}
   */

var events = ['dragstart', 'drag', 'dragend'];
var script = mixins(injectMap).extend({
  name: 'MapboxMarker',
  components: {
    MapboxPopup: __vue_component__$1
  },
  props: props,
  data: function data() {
    return {
      marker: null
    };
  },
  computed: {
    hasPopup: function hasPopup() {
      return this.popup !== false && this.$refs.popup !== undefined;
    },
    popupInstance: function popupInstance() {
      return this.hasPopup ? this.$refs.popup.popup : null;
    },
    popupOptions: function popupOptions() {
      if (_typeof(this.popup) === 'object') {
        return __assign(__assign({
          lngLat: this.lngLat
        }, this.popup), {
          renderless: true
        });
      } else return null;
    },
    options: function options() {
      // eslint-disable-next-line no-unused-vars
      var _a = this.$props,
          lngLat = _a.lngLat,
          popup = _a.popup,
          options = __rest(_a, ["lngLat", "popup"]); // Use current component's element if container is not set


      if (this.$slots.default) {
        options.element = this.$refs.content;
      }

      return options;
    }
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _a.sent();
            this.marker = new Marker(this.options).setLngLat(this.lngLat).addTo(map); // Bind props and events

            bindProps(this, this.marker, props);
            bindEvents(this, this.marker, events);

            if (this.hasPopup && this.popupInstance) {
              this.marker.setPopup(this.popupInstance);
            }

            return [2
            /*return*/
            ];
        }
      });
    });
  },
  destroyed: function destroyed() {
    if (this.marker) {
      unbindEvents(this, this.marker);
      this.marker.remove();
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', [_c('div', {
    ref: "content"
  }, [_vm._t("default")], 2), _vm._v(" "), _vm.popup ? _c('mapbox-popup', _vm._b({
    ref: "popup"
  }, 'mapbox-popup', _vm.popupOptions, false), [_vm._t("popup")], 2) : _vm._e()], 1);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxMarker.ts.map
