import { b as __rest, _ as __awaiter, a as __generator, n as normalizeComponent } from '../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import { Popup } from 'mapbox-gl';
import injectMap from '../mixins/injectMap.ts';
import { unbindEvents, bindEvents } from '../utils/bind-events.ts';
import bindProps from '../utils/bind-props.ts';

/**
   * Component's props definition, we need to declare it outside the component
   * to be able to test the default values and the types.
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#popup
   * @type {Object}
   */

var props = {
  lngLat: {
    type: Object,
    required: true
  },
  closeButton: {
    type: Boolean,
    default: true
  },
  closeOnClick: {
    type: Boolean,
    default: true
  },
  closeOnMove: {
    type: Boolean,
    default: false
  },
  anchor: {
    type: String,
    default: null
  },
  offset: {
    type: Object,
    default: null
  },
  className: {
    type: String,
    default: null
  },
  maxWidth: {
    type: String,
    default: '240px'
  },

  /**
     * Do not render the popup on the map.
     * @type {Object}
     */
  renderless: {
    type: Boolean,
    default: false,
    bind: false
  }
};
/**
   * All Map events which will be mapped/bounded to the component
   * @see  https://docs.mapbox.com/mapbox-gl-js/api/#popup.event:open
   * @type {Array}
   */

var events = ['open', 'close'];
var script = mixins(injectMap).extend({
  name: 'MapboxPopup',
  props: props,
  data: function data() {
    return {
      popup: null
    };
  },
  computed: {
    options: function options() {
      // eslint-disable-next-line no-unused-vars
      var _a = this.$props,
          lngLat = _a.lngLat,
          options = __rest(_a, ["lngLat"]);

      return options;
    }
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var map;
      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            return [4
            /*yield*/
            , this.map.promise];

          case 1:
            map = _a.sent();
            this.popup = new Popup(this.options).setLngLat(this.lngLat).setDOMContent(this.$el);

            if (!this.renderless) {
              this.popup.addTo(map);
            }

            bindProps(this, this.popup, props);
            bindEvents(this, this.popup, events);
            this.$emit('mb-open', this.popup);
            return [2
            /*return*/
            ];
        }
      });
    });
  },
  destroyed: function destroyed() {
    if (this.popup) {
      unbindEvents(this, this.popup);
      this.popup.remove();
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', [_vm._t("default")], 2);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

export default __vue_component__;
//# sourceMappingURL=MapboxPopup.ts.map
