import { _ as __awaiter, a as __generator, n as normalizeComponent, b as __rest, c as __assign } from '../../_chunks/normalize-component.2d07400a.js';
import mixins from 'vue-typed-mixins';
import 'mapbox-gl';
import '@mapbox/mapbox-gl-geocoder';
import injectMap from '../../mixins/injectMap.ts';
import '../../utils/bind-events.ts';
import __vue_component__$3 from '../MapboxGeocoder.ts';
import '../MapboxLayer.ts';
import '../../utils/bind-props.ts';
import 'my-deferred';
import '../../mixins/provideMap.ts';
import __vue_component__$4 from '../MapboxMap.ts';
import '../MapboxSource.ts';
import '../../utils/uniq-id.ts';
import __vue_component__$2 from '../MapboxCluster.ts';

var script = mixins().extend({
  data: function data() {
    return {
      scrollTop: 0,
      scrollMax: Infinity,
      debouncedSetVars: null
    };
  },
  updated: function updated() {
    this.setVars();
  },
  mounted: function mounted() {
    return __awaiter(this, void 0, void 0, function () {
      var timer;

      var _this = this;

      return __generator(this, function (_a) {
        switch (_a.label) {
          case 0:
            this.$refs.scroller.addEventListener('scroll', function () {
              return _this.setVars();
            }, {
              passive: true
            });

            this.debouncedSetVars = function (_ev) {
              clearTimeout(timer);
              timer = setTimeout(function () {
                return _this.setVars();
              }, 300);
            };

            window.addEventListener('resize', this.debouncedSetVars);
            return [4
            /*yield*/
            , this.$nextTick()];

          case 1:
            _a.sent();

            this.setVars();
            return [2
            /*return*/
            ];
        }
      });
    });
  },
  beforeDestroy: function beforeDestroy() {
    this.$refs.scroller.removeEventListener('scroll', this.setVars);
    if (this.debouncedSetVars) window.removeEventListener('resize', this.debouncedSetVars);
  },
  methods: {
    setVars: function setVars() {
      var scroller = this.$refs.scroller;

      if (!scroller) {
        return;
      }

      this.scrollTop = scroller.scrollTop;
      this.scrollMax = scroller.scrollHeight - scroller.clientHeight;

      if (this.scrollTop === 0) {
        this.$emit('scroll-top');
      }

      if (this.scrollTop === this.scrollMax) {
        this.$emit('scoll-bottom');
      }
    }
  }
});

/* script */
var __vue_script__ = script;
/* template */

var __vue_render__ = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    staticClass: "scroller",
    class: {
      'scroller--is-top': _vm.scrollTop === 0,
      'scroller--is-bottom': _vm.scrollTop === _vm.scrollMax,
      'scroller--has-no-scroll': _vm.scrollTop === 0 && _vm.scrollMax === 0
    }
  }, [_c('div', {
    ref: "scroller",
    staticClass: "scroller__inner"
  }, [_c('div', {
    staticClass: "scroller__content"
  }, [_vm._t("default")], 2)])]);
};

var __vue_staticRenderFns__ = [];
/* style */

var __vue_inject_styles__ = undefined;
/* scoped */

var __vue_scope_id__ = undefined;
/* module identifier */

var __vue_module_identifier__ = undefined;
/* functional template */

var __vue_is_functional_template__ = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__ = /*#__PURE__*/normalizeComponent({
  render: __vue_render__,
  staticRenderFns: __vue_staticRenderFns__
}, __vue_inject_styles__, __vue_script__, __vue_scope_id__, __vue_is_functional_template__, __vue_module_identifier__, false, undefined, undefined, undefined);

var script$1 = mixins(injectMap).extend({
  components: {
    MapboxCluster: __vue_component__$2,
    MapboxGeocoder: __vue_component__$3,
    MapboxMap: __vue_component__$4,
    VueScroller: __vue_component__
  },
  props: {
    test: {
      type: Boolean,
      default: false
    },
    items: {
      type: Array,
      default: function _default() {
        return [];
      },
      required: true
    },
    itemZoomLevel: {
      type: Number,
      default: 14
    },
    accessToken: {
      type: String,
      default: 'no-token'
    },
    mapboxMap: {
      type: Object,
      default: function _default() {}
    },
    mapboxCluster: {
      type: Object,
      default: function _default() {}
    },
    mapboxGeocoder: {
      type: Object,
      default: function _default() {}
    },
    transitions: {
      type: Object,
      default: function _default() {
        return {
          loader: {
            map: {},
            search: {},
            list: {},
            default: {}
          },
          panel: {}
        };
      }
    },
    classes: {
      type: Object,
      default: function _default() {
        var root = 'store-locator';

        var bem = function bem(name, modifier) {
          if (modifier === void 0) {
            modifier = '';
          }

          return root + "__" + name + (modifier ? "--" + modifier : '');
        };

        return {
          root: root,
          region: {
            map: [bem('region'), bem('region', 'map')],
            search: [bem('region'), bem('region', 'search')],
            list: [bem('region'), bem('region', 'list')],
            panel: [bem('region'), bem('region', 'panel')]
          },
          map: bem('map'),
          search: bem('search'),
          list: bem('list'),
          listItem: bem('list-item'),
          panel: bem('panel')
        };
      }
    }
  },
  data: function data() {
    return {
      isLoading: true,
      map: null,
      mapIsMoving: false,
      selectedItem: null,
      // filteredItems: this.items.map((item) => item),
      listIsLoading: false
    };
  },
  computed: {
    filteredItems: function filteredItems() {
      return this.items.filter(function (item) {
        return !!item;
      });
    },
    geoJson: function geoJson() {
      return {
        type: 'FeatureCollection',
        features: this.items.map(this.itemToGeoJsonFeature)
      };
    },
    filteredGeoJson: function filteredGeoJson() {
      return {
        type: 'FeatureCollection',
        features: this.filteredItems.map(this.itemToGeoJsonFeature)
      };
    }
  },
  methods: {
    itemToGeoJsonFeature: function itemToGeoJsonFeature(_a) {
      var lat = _a.lat,
          lng = _a.lng,
          properties = __rest(_a, ["lat", "lng"]);

      return {
        type: 'Feature',
        geometry: {
          type: 'Point',
          coordinates: [lng, lat]
        },
        properties: properties
      };
    },
    geoJsonFeatureToItem: function geoJsonFeatureToItem(_a) {
      var geometry = _a.geometry,
          properties = _a.properties;
      return __assign({
        lat: geometry.coordinates[1],
        lng: geometry.coordinates[0]
      }, properties);
    },
    onGeocoderResult: function onGeocoderResult(_a) {
      var result = _a.result;
      return __awaiter(this, void 0, void 0, function () {
        var map;
        return __generator(this, function (_b) {
          switch (_b.label) {
            case 0:
              return [4
              /*yield*/
              , this.map.promise];

            case 1:
              map = _b.sent();

              if (result.bbox) {
                map.fitBounds(result.bbox);
              } else if (result.center && map) {
                map.flyTo({
                  center: result.center
                });
              }

              return [2
              /*return*/
              ];
          }
        });
      });
    },
    onGeocoderCreated: function onGeocoderCreated(geocoder) {
      this.$emit('geocoder-created', geocoder);
    },
    onMapCreated: function onMapCreated(instance) {
      return __awaiter(this, void 0, void 0, function () {
        return __generator(this, function (_a) {
          this.map = instance;
          this.$emit('map-created', instance);
          this.filterFeaturesInView();
          return [2
          /*return*/
          ];
        });
      });
    },
    onMapLoad: function onMapLoad() {
      return __awaiter(this, void 0, void 0, function () {
        return __generator(this, function (_a) {
          switch (_a.label) {
            case 0:
              return [4
              /*yield*/
              , this.$nextTick()];

            case 1:
              _a.sent();

              this.isLoading = false;

              if (this.$listeners.load) {
                console.warn('[StoreLocator]', 'The `@load` event is deprecated, replace it with the `@map-load` event instead.');
              }

              this.$emit('load', this.map);
              this.$emit('map-load', this.map);
              return [2
              /*return*/
              ];
          }
        });
      });
    },
    onMapMovestart: function onMapMovestart() {
      var _this = this;

      this.mapIsMoving = true;
      this.$nextTick(function () {
        _this.listIsLoading = true;
      });
    },
    onMapMoveend: function onMapMoveend() {
      this.mapIsMoving = false;
      this.filterFeaturesInView();
    },

    /**
         * Filter the features in view.
         */
    filterFeaturesInView: function filterFeaturesInView() {
      return __awaiter(this, void 0, void 0, function () {
        var mapBounds, center;
        return __generator(this, function (_a) {
          switch (_a.label) {
            case 0:
              this.listIsLoading = true;
              mapBounds = this.map.getBounds();
              center = this.map.getCenter();
              this.filteredItems = this.items.filter(function (_a) {
                var lng = _a.lng,
                    lat = _a.lat;
                return mapBounds.contains([lng, lat]);
              }).sort(function (a, b) {
                var distanceFromA = center.distanceTo(a);
                var distanceFromB = center.distanceTo(b);

                if (distanceFromA < distanceFromB) {
                  return -1;
                }

                if (distanceFromA > distanceFromB) {
                  return 1;
                }

                return 0;
              });
              return [4
              /*yield*/
              , this.$nextTick()];

            case 1:
              _a.sent();

              this.listIsLoading = false;
              return [2
              /*return*/
              ];
          }
        });
      });
    },

    /**
         * Handler for the click event on a list item.
         * @param {Feature} store A GeoJSON feature.;
         */
    onListItemClick: function onListItemClick(item) {
      this.selectedItem = item;
      this.$emit('select-item', item);

      var _a = this.map.getCenter(),
          lat = _a.lat,
          lng = _a.lng; // Do not trigger flyTo if the map is almost already centered


      if (Math.abs(lng - item.lng) > 0.0001 && Math.abs(lat - item.lat) > 0.0001) {
        this.map.flyTo({
          center: [item.lng, item.lat],
          zoom: this.itemZoomLevel
        });
      }
    },

    /**
         * Handler for the click event on a GeoJSON feature.
         *
         * @param  {Feature} feature The GeoJSON feature being clicked.
         */
    onClusterFeatureClick: function onClusterFeatureClick(feature, event) {
      var item = this.items.find(function (_a) {
        var id = _a.id;
        return id === feature.properties.id;
      });
      this.$emit('cluster-feature-click', feature, event);

      if (item) {
        this.$emit('select-item', item);
        this.selectedItem = item;
        this.map.flyTo({
          center: feature.geometry.coordinates,
          zoom: this.itemZoomLevel
        });
      }
    },
    onClusterFeatureMouseenter: function onClusterFeatureMouseenter() {
      var args = [];

      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }

      this.$emit('cluster-feature-mouseenter', args);
    },
    onClusterFeatureMouseleave: function onClusterFeatureMouseleave() {
      var args = [];

      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }

      this.$emit('cluster-feature-mouseleave', args);
    },
    onClusterClusterClick: function onClusterClusterClick() {
      var args = [];

      for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
      }

      this.$emit('cluster-cluster-click', args);
    }
  }
});

/* script */
var __vue_script__$1 = script$1;
/* template */

var __vue_render__$1 = function __vue_render__() {
  var _vm = this;

  var _h = _vm.$createElement;

  var _c = _vm._self._c || _h;

  return _c('div', {
    class: _vm.classes.root || {}
  }, [_c('div', {
    class: (_vm.classes.region || {}).map || {}
  }, [_vm.isLoading ? [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).map || {}, false), [_vm._t("map-loader", [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).default || {}, false), [_vm._t("loader", [_vm._v("\n              Loading...\n            ")])], 2)])], 2)] : _vm._e(), _vm._v(" "), _vm._t("before-map"), _vm._v(" "), _c('mapbox-map', _vm._b({
    class: _vm.classes.map || {},
    on: {
      "mb-created": _vm.onMapCreated,
      "mb-movestart": _vm.onMapMovestart,
      "mb-moveend": _vm.onMapMoveend,
      "mb-load": _vm.onMapLoad
    }
  }, 'mapbox-map', Object.assign({}, _vm.mapboxMap, {
    accessToken: _vm.accessToken
  }), false), [_c('mapbox-cluster', _vm._b({
    on: {
      "mb-feature-click": _vm.onClusterFeatureClick,
      "mb-feature-mouseenter": _vm.onClusterFeatureMouseenter,
      "mb-feature-mouseleave": _vm.onClusterFeatureMouseleave,
      "mb-cluster-click": _vm.onClusterClusterClick
    }
  }, 'mapbox-cluster', Object.assign({}, _vm.mapboxCluster, {
    data: _vm.filteredGeoJson
  }), false)), _vm._v(" "), _vm._t("map", null, {
    "map": _vm.map,
    "geojson": _vm.geoJson,
    "filteredGeojson": _vm.filteredGeoJson,
    "items": _vm.items,
    "filteredItems": _vm.filteredItems,
    "selectedItem": _vm.selectedItem
  })], 2), _vm._v(" "), _vm._t("after-map")], 2), _vm._v(" "), _c('div', {
    class: (_vm.classes.region || {}).search || {}
  }, [_vm.isLoading ? [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).search || {}, false), [_vm._t("search-loader", [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).default || {}, false), [_vm._t("loader", [_vm._v("\n              Loading...\n            ")])], 2)])], 2)] : _vm._e(), _vm._v(" "), _vm._t("before-search", null, {
    "items": _vm.items,
    "filteredItems": _vm.filteredItems,
    "selectedItem": _vm.selectedItem
  }), _vm._v(" "), _c('mapbox-geocoder', _vm._b({
    class: _vm.classes.search || {},
    on: {
      "mb-result": _vm.onGeocoderResult,
      "mb-created": _vm.onGeocoderCreated
    }
  }, 'mapbox-geocoder', Object.assign({}, _vm.mapboxGeocoder, {
    accessToken: _vm.accessToken
  }), false)), _vm._v(" "), _vm._t("after-search", null, {
    "items": _vm.items,
    "filteredItems": _vm.filteredItems,
    "selectedItem": _vm.selectedItem
  })], 2), _vm._v(" "), _c('div', {
    class: (_vm.classes.region || {}).list || {}
  }, [_vm.isLoading || _vm.listIsLoading ? [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).list || {}, false), [_vm._t("list-loader", [_c('transition', _vm._b({}, 'transition', (_vm.transitions.loader || {}).default || {}, false), [_vm._t("loader", [_vm._v("\n              Loading...\n            ")])], 2)])], 2)] : [_vm._t("before-list", [_c('p', [_vm._v("Result(s): " + _vm._s(_vm.filteredItems.length.toFixed(0)))])], {
    "items": _vm.items,
    "filteredItems": _vm.filteredItems,
    "selectedItem": _vm.selectedItem
  }), _vm._v(" "), _vm.filteredItems.length > 0 ? _c('vue-scroller', [_c('ul', {
    class: _vm.classes.list || {}
  }, _vm._l(_vm.filteredItems, function (item, index) {
    return _c('li', {
      key: item.id,
      class: _vm.classes.listItem || {},
      on: {
        "click": function click($event) {
          return _vm.onListItemClick(item);
        }
      }
    }, [_vm._t("list-item", [_vm._v("\n              Lat: " + _vm._s(item.lat) + " "), _c('br'), _vm._v("\n              Lng: " + _vm._s(item.lng) + "\n            ")], {
      "item": item,
      "index": index,
      "selectedItem": _vm.selectedItem
    })], 2);
  }), 0)]) : _vm._e(), _vm._v(" "), _vm._t("after-list", null, {
    "items": _vm.items,
    "filteredItems": _vm.filteredItems,
    "selectedItem": _vm.selectedItem,
    "filterFeaturesInView": _vm.filterFeaturesInView
  })]], 2), _vm._v(" "), _c('div', {
    class: (_vm.classes.region || {}).panel || {}
  }, [_c('transition', _vm._b({}, 'transition', _vm.transitions.panel || {}, false), [_vm.selectedItem ? _c('div', {
    key: _vm.selectedItem.id,
    class: _vm.classes.panel || {}
  }, [_vm._t("panel", [_c('div', [_vm._v(_vm._s(_vm.selectedItem))])], {
    "item": _vm.selectedItem,
    "close": function close() {
      return _vm.selectedItem = null;
    }
  })], 2) : _vm._e()])], 1)]);
};

var __vue_staticRenderFns__$1 = [];
/* style */

var __vue_inject_styles__$1 = undefined;
/* scoped */

var __vue_scope_id__$1 = undefined;
/* module identifier */

var __vue_module_identifier__$1 = undefined;
/* functional template */

var __vue_is_functional_template__$1 = false;
/* style inject */

/* style inject SSR */

/* style inject shadow dom */

var __vue_component__$1 = /*#__PURE__*/normalizeComponent({
  render: __vue_render__$1,
  staticRenderFns: __vue_staticRenderFns__$1
}, __vue_inject_styles__$1, __vue_script__$1, __vue_scope_id__$1, __vue_is_functional_template__$1, __vue_module_identifier__$1, false, undefined, undefined, undefined);

export default __vue_component__$1;
//# sourceMappingURL=index.ts.map
